"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createShopifyCoreAsyncOptionsProvider = exports.createShopifyCoreAsyncOptionsProviders = void 0;
const core_constants_1 = require("./core.constants");
function createShopifyCoreAsyncOptionsProviders(options) {
    if (options.useExisting || options.useFactory) {
        return [createShopifyCoreAsyncOptionsProvider(options)];
    }
    if (options.useClass) {
        return [
            createShopifyCoreAsyncOptionsProvider(options),
            { provide: options.useClass, useClass: options.useClass },
        ];
    }
    throw new Error('Invalid ShopifyCore options: one of `useClass`, `useExisting` or `useFactory` should be defined.');
}
exports.createShopifyCoreAsyncOptionsProviders = createShopifyCoreAsyncOptionsProviders;
function createShopifyCoreAsyncOptionsProvider(options) {
    if (options.useFactory) {
        return {
            provide: core_constants_1.SHOPIFY_CORE_OPTIONS,
            useFactory: options.useFactory,
            inject: options.inject || [],
        };
    }
    const inject = [];
    if (options.useClass) {
        inject.push(options.useClass);
    }
    else if (options.useExisting) {
        inject.push(options.useExisting);
    }
    return {
        provide: core_constants_1.SHOPIFY_CORE_OPTIONS,
        useFactory: (optionsFactory) => optionsFactory.createShopifyCoreOptions(),
        inject,
    };
}
exports.createShopifyCoreAsyncOptionsProvider = createShopifyCoreAsyncOptionsProvider;
//# sourceMappingURL=core.providers.js.map